@@ -1,6 +1,6 @@
 // Filename: pipeline.rs
-// Version:	 0.4
-// Date:	 15-09-2021 (DD-MM-YYYY)
+// Version:	 0.5
+// Date:	 24-09-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -33,6 +33,8 @@ pub struct PipelineConfig {
     /// The ID of the scheduler the pipeline uses, if any. Multiple pipelines with the same
     /// scheduler ID share a scheduler among them.
     pub scheduler_id: Option<usize>,
+    /// How many clock cycles are dedicated to reading register data.
+    pub register_read_cycles: usize,
     /// If the pipeline can execute instructions exclusively using the general purpose register
     /// file.
     pub general_purpose: bool,
