@@ -54,6 +54,8 @@ pub struct CPUModel {
     pub schedulers: Vec<component_config::SchedulerConfig>,
     /// Configuration for each pipeline from front end to the last stage.
     pub pipelines: Vec<component_config::PipelineConfig>,
+    /// Configuration of the load-store-unit.
+    pub load_store_unit_config: component_config::LoadStoreUnitConfig,
 }
 
 /// Defines the amount of clock cycles each instruction type needs.
@@ -97,6 +99,7 @@ impl CPUModel {
             reg_file_config: Default::default(),
             schedulers: Vec::new(),
             pipelines: Vec::new(),
+            load_store_unit_config: Default::default(),
         }
     }
 }
